@@ -13,7 +13,7 @@
 # limitations under the License.
 
 import os
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 from appium.common.helper import encode_file_to_base64
 from appium.webdriver.extensions.flutter_integration.flutter_finder import FlutterFinder
@@ -172,6 +172,104 @@ class FlutterCommand:
         """
         self.execute_flutter_command('activateInjectedImage', {'imageId': image_id})
 
+    def get_render_tree(
+        self,
+        widget_type: Optional[str] = None,
+        key: Optional[str] = None,
+        text: Optional[str] = None,
+    ) -> List[Optional[Dict]]:
+        """
+        Returns the render tree of the root widget.
+
+        Args:
+            widget_type (Optional[str]): The type of the widget to primary filter by.
+            key (Optional[str]): The key of the widget to filter by.
+            text (Optional[str]): The text of the widget to filter by.
+
+        Returns:
+            List[Optional[Dict]]: A list of dictionaries or None values representing the render tree.
+
+            The result is a nested list of dictionaries representing each widget and its properties,
+            such as type, key, size, attribute, state, visual information, and hierarchy.
+
+            The example widget includes the following code, which is rendered as part of the widget tree:
+            ```dart
+            Semantics(
+              key: const Key('add_activity_semantics'),
+              label: 'add_activity_button',
+              button: true,
+              child: FloatingActionButton.small(
+                key: const Key('add_activity_button'),
+                tooltip: 'add_activity_button',
+                heroTag: 'add',
+                backgroundColor: const Color(0xFF2E2E3A),
+                onPressed: null,
+                child: Icon(
+                  Icons.add,
+                  size: 16,
+                  color: Colors.amber.shade200.withOpacity(0.5),
+                  semanticLabel: 'Add icon',
+                ),
+              ),
+            ),
+            ```
+            Example execute command:
+            >>> flutter_command = FlutterCommand(driver)  # noqa
+            >>> flutter_command.get_render_tree(widget_type='Semantics', key='add_activity_semantics')
+            output >> [
+                        {
+                            "type": "Semantics",
+                            "elementType": "SingleChildRenderObjectElement",
+                            "description": "Semantics-[<'add_activity_semantics'>]",
+                            "depth": 0,
+                            "key": "[<'add_activity_semantics'>]",
+                            "attributes": {
+                                "semanticsLabel": "add_activity_button"
+                            },
+                            "visual": {},
+                            "state": {},
+                            "rect": {
+                                "x": 0,
+                                "y": 0,
+                                "width": 48,
+                                "height": 48
+                            },
+                            "children": [
+                                {
+                                    "type": "FloatingActionButton",
+                                    "elementType": "StatelessElement",
+                                    "description": "FloatingActionButton-[<'add_activity_button'>]",
+                                    "depth": 1,
+                                    "key": "[<'add_activity_button'>]",
+                                    "attributes": {},
+                                    "visual": {},
+                                    "state": {},
+                                    "rect": {
+                                        "x": 0,
+                                        "y": 0,
+                                        "width": 48,
+                                        "height": 48
+                                    },
+                                    "children": [
+                                        {...},
+                                            "children": [...]
+                                        }
+                                    ]
+                                }
+                            ]
+                        }
+                    ]
+        """
+        opts = {}
+        if widget_type is not None:
+            opts['widgetType'] = widget_type
+        if key is not None:
+            opts['key'] = key
+        if text is not None:
+            opts['text'] = text
+
+        return self.execute_flutter_command('renderTree', opts)
+
     def execute_flutter_command(self, scriptName: str, params: dict) -> Any:
         """
         Executes a Flutter command by sending a script and parameters to the flutter integration driver.
